## Topsis_Harshita_Saxena

# TOPSIS

**Submitted By**: Harshita Saxena - 102003497.

Description: **Evaluation of alternatives based on multiple criteria using TOPSIS method.**.

---

## How to install this package:

```
>> pip install Topsis_Harshita_Saxena_102003497
```

### In Command Prompt

```
>> python <program.py> <InputDataFile> <Weights> <Impacts> <ResultFileName>
```
